Constrained, Krylov, MLE, and proximal restoration algorithms.
Use this module when you need solver families beyond the common
crate::iterative and crate::spectral entry points, such as Nnls
or Fista.
Structs
- Bvls
- Configuration for bounded-variable least-squares deconvolution.
- Cgls
- Configuration for conjugate-gradient least-squares deconvolution.
- Cmle
- Configuration for classical maximum-likelihood estimation.
- Fista
- Configuration for accelerated iterative shrinkage-thresholding deconvolution.
- Gmle
- Configuration for Gaussian maximum-likelihood estimation.
- Hybr
- Configuration for hybrid Krylov deconvolution with Tikhonov damping.
- Ista
- Configuration for iterative shrinkage-thresholding deconvolution.
- Mrnsd
- Configuration for modified residual norm steepest descent.
- Nnls
- Configuration for non-negative least-squares deconvolution.
- Qmle
- Configuration for quadratic maximum-likelihood estimation.
- Wpl
- Configuration for weighted Poisson likelihood deconvolution.
Enums
- Sparse
Basis - Sparse representation used by proximal solvers.
Functions
- bvls
- Restore an image with bounded-variable least squares and default settings.
- bvls_
with - Restore an image with bounded-variable least squares and explicit settings.
- cgls
- Restore an image with conjugate-gradient least squares.
- cgls_
with - Restore an image with CGLS and explicit settings.
- cmle
- Restore an image with classical maximum-likelihood estimation.
- cmle_
with - Restore an image with CMLE and explicit settings.
- fista
- Restore an image with accelerated iterative shrinkage-thresholding.
- fista_
with - Restore an image with FISTA and explicit settings.
- gmle
- Restore an image with Gaussian maximum-likelihood estimation.
- gmle_
with - Restore an image with GMLE and explicit settings.
- hybr
- Restore an image with hybrid Krylov iteration and Tikhonov damping.
- hybr_
with - Restore an image with HyBR and explicit settings.
- ista
- Restore an image with iterative shrinkage-thresholding.
- ista_
with - Restore an image with ISTA and explicit settings.
- mrnsd
- Restore an image with modified residual norm steepest descent.
- mrnsd_
with - Restore an image with MRNSD and explicit settings.
- nnls
- Restore an image with non-negative least squares and default settings.
- nnls_
with - Restore an image with non-negative least squares and explicit settings.
- qmle
- Restore an image with quadratic maximum-likelihood estimation.
- qmle_
with - Restore an image with QMLE and explicit settings.
- wpl
- Restore an image with weighted Poisson likelihood iteration.
- wpl_
with - Restore an image with WPL and explicit settings.